@@ -149,6 +149,9 @@ class VariableClUpdateRepName(Variable):
     type = "list"
     value = []
 
+    def humanReadable(self):
+        return [x.capitalize() for x in self.Get()]
+
 
 class VariableClUpdateRepUrl(Variable):
     """
@@ -479,7 +482,7 @@ class VariableClUpdateSyncRep(Variable):
         return list(reversed(self.rep_name))
 
     def choice(self):
-        return self.rep_name
+        return [ (x, x.capitalize()) for x in self.rep_name]
 
 
 class VariableClUpdateSyncOverlayRep(ReadonlyVariable):
@@ -799,8 +802,12 @@ class VariableClUpdateProfileDependData(ReadonlyTableVariable):
         # испольуется для инициализации
         # url = self.Get('cl_update_profile_url').lower()
         if dv:
-            return reversed(zip(dv.Get('cl_update_rep_name'),
-                                dv.Get('cl_update_rep_url')))
+            if hr == HumanReadable.Yes:
+                return reversed(zip([x.capitalize() for x in dv.Get('cl_update_rep_name')],
+                                    dv.Get('cl_update_rep_url')))
+            else:
+                return reversed(zip(dv.Get('cl_update_rep_name'),
+                                    dv.Get('cl_update_rep_url')))
         return ""
 
     setValue = Variable.setValue
